@@ -53,20 +53,21 @@ DEFAULT_DICT_SIZE = 100000
 ARTICLE_MIN_CHARS = 500
 
 
-RE_P0 = re.compile('<!--.*?-->', re.DOTALL | re.UNICODE)
-RE_P1 = re.compile('<ref([> ].*?)(</ref>|/>)', re.DOTALL | re.UNICODE)
-RE_P2 = re.compile("(\n\[\[[a-z][a-z][\w-]*:[^:\]]+\]\])+$", re.UNICODE)
-RE_P3 = re.compile("{{([^}{]*)}}", re.DOTALL | re.UNICODE)
-RE_P4 = re.compile("{{([^}]*)}}", re.DOTALL | re.UNICODE)
-RE_P5 = re.compile('\[(\w+):\/\/(.*?)(( (.*?))|())\]', re.UNICODE)
-RE_P6 = re.compile("\[([^][]*)\|([^][]*)\]", re.DOTALL | re.UNICODE)
-RE_P7 = re.compile('\n\[\[[iI]mage(.*?)(\|.*?)*\|(.*?)\]\]', re.UNICODE)
-RE_P8 = re.compile('\n\[\[[fF]ile(.*?)(\|.*?)*\|(.*?)\]\]', re.UNICODE)
-RE_P9 = re.compile('<nowiki([> ].*?)(</nowiki>|/>)', re.DOTALL | re.UNICODE)
-RE_P10 = re.compile('<math([> ].*?)(</math>|/>)', re.DOTALL | re.UNICODE)
-RE_P11 = re.compile('<(.*?)>', re.DOTALL | re.UNICODE)
-RE_P12 = re.compile('\n(({\|)|(\|-)|(\|}))(.*?)(?=\n)', re.UNICODE)
-RE_P13 = re.compile('\n(\||\!)(.*?\|)*([^|]*?)', re.UNICODE)
+RE_P0 = re.compile('<!--.*?-->', re.DOTALL | re.UNICODE) # comments
+RE_P1 = re.compile('<ref([> ].*?)(</ref>|/>)', re.DOTALL | re.UNICODE) # footnotes
+RE_P2 = re.compile("(\n\[\[[a-z][a-z][\w-]*:[^:\]]+\]\])+$", re.UNICODE) # links to languages
+RE_P3 = re.compile("{{([^}{]*)}}", re.DOTALL | re.UNICODE) # template
+RE_P4 = re.compile("{{([^}]*)}}", re.DOTALL | re.UNICODE) # template
+RE_P5 = re.compile('\[(\w+):\/\/(.*?)(( (.*?))|())\]', re.UNICODE) # remove URL, keep description
+RE_P6 = re.compile("\[([^][]*)\|([^][]*)\]", re.DOTALL | re.UNICODE) # simplify links, keep description
+RE_P7 = re.compile('\n\[\[[iI]mage(.*?)(\|.*?)*\|(.*?)\]\]', re.UNICODE) # keep description of images
+RE_P8 = re.compile('\n\[\[[fF]ile(.*?)(\|.*?)*\|(.*?)\]\]', re.UNICODE) # keep description of files
+RE_P9 = re.compile('<nowiki([> ].*?)(</nowiki>|/>)', re.DOTALL | re.UNICODE) # outside links
+RE_P10 = re.compile('<math([> ].*?)(</math>|/>)', re.DOTALL | re.UNICODE) # math content
+RE_P11 = re.compile('<(.*?)>', re.DOTALL | re.UNICODE) # all other tags
+RE_P12 = re.compile('\n(({\|)|(\|-)|(\|}))(.*?)(?=\n)', re.UNICODE) # table formatting
+RE_P13 = re.compile('\n(\||\!)(.*?\|)*([^|]*?)', re.UNICODE) # table cell formatting
+RE_P14 = re.compile('\[\[Category:[^][]*\]\]', re.UNICODE) # categories
 
 
 def filter_wiki(raw):
@@ -78,6 +79,10 @@ def filter_wiki(raw):
     # contributions to improving this code are welcome :)
     text = utils.decode_htmlentities(utils.to_unicode(raw, 'utf8', errors='ignore'))
     text = utils.decode_htmlentities(text) # '&amp;nbsp;' --> '\xa0'
+    return remove_markup(text)
+
+
+def remove_markup(text):
     text = re.sub(RE_P2, "", text) # remove the last list (=languages)
     # the wiki markup is recursive (markup inside markup etc)
     # instead of writing a recursive grammar, here we deal with that by removing
@@ -94,6 +99,7 @@ def filter_wiki(raw):
         # remove templates (no recursion)
         text = re.sub(RE_P3, '', text)
         text = re.sub(RE_P4, '', text)
+        text = re.sub(RE_P14, '', text) # remove categories
         text = re.sub(RE_P5, '\\3', text) # remove urls, keep description
         text = re.sub(RE_P7, '\n\\3', text) # simplify images, keep description only
         text = re.sub(RE_P8, '\n\\3', text) # simplify files, keep description only
